@@ -108,6 +108,9 @@
 - (EOAdaptorChannel *) acquireQuickChannel;
 - (EOAdaptorChannel *) acquireAclChannel;
 - (void) releaseChannel: (EOAdaptorChannel *) _channel;
+- (void) releaseChannel: (EOAdaptorChannel *) _channel
+            immediately: (BOOL) _immediately;
+
 
 - (BOOL) canConnectStore;
 - (BOOL) canConnectQuick;
@@ -156,10 +159,6 @@
 /* helpers */
 
 - (EOAttribute *) _attributeForColumn: (NSString *) _field;
-- (void) _findQualifiers: (id) qualifier
-             withAdaptor: (EOAdaptor *) adaptor;
-- (void) _formatQualifierValue: (EOKeyValueQualifier *) qualifier
-                   withAdaptor: (EOAdaptor *) adaptor;
 @end
 
 #endif /* __GDLContentStore_GCSFolder_H__ */
