@@ -37,6 +37,7 @@
 #import "GCSChannelManager.h"
 #import "EOAdaptorChannel+GCS.h"
 #import "GCSAlarmsFolder.h"
+#import "GCSAdminFolder.h"
 #import "GCSFolder.h"
 #import "GCSFolderType.h"
 #import "GCSSessionsFolder.h"
@@ -497,6 +498,12 @@ static BOOL       _singleStoreMode           = NO;
   return [GCSSessionsFolder sessionsFolderWithFolderManager: self];
 }
 
+/* admin */
+- (GCSAdminFolder *) adminFolder
+{
+  return [GCSAdminFolder adminFolderWithFolderManager: self];
+}
+
 - (NSString *)generateSQLWhereForInternalNames:(NSArray *)_names
 				    exactMatch:(BOOL)_beExact orDirectSubfolderMatch:(BOOL)_directSubs
 {
