@@ -135,7 +135,8 @@
              [currentStartDate compare: endDate] == NSOrderedSame)
         {
           currentEndDate = [currentStartDate addTimeInterval: [firstRange duration]];
-          if ([startDate compare: currentEndDate] == NSOrderedAscending)
+          if ([startDate compare: currentEndDate] == NSOrderedAscending ||
+              ([firstRange duration] == 0 && [startDate compare: currentEndDate] == NSOrderedSame))
             {
               NGCalendarDateRange *r;
 
@@ -162,7 +163,8 @@
 
           currentEndDate = [currentStartDate addTimeInterval: [firstRange duration]];
           if (hasRepeatCount ||
-              [startDate compare: currentEndDate] == NSOrderedAscending)
+              [startDate compare: currentEndDate] == NSOrderedAscending ||
+              ([startDate compare: currentEndDate] == NSOrderedSame && [firstRange duration] == 0))
             {
               // If the rule count is defined, stop once the count is reached.
               if ([currentStartDate compare: firStart] == NSOrderedSame)
