@@ -1,6 +1,6 @@
 /* MSExchangeFreeBusy.m - this file is part of SOGo
  *
- * Copyright (C) 2012-2014 Inverse inc.
+ * Copyright (C) 2012-2016 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,9 +18,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#import <Foundation/NSBundle.h>
-#import <Foundation/NSCalendarDate.h>
-#import <Foundation/NSDictionary.h>
 
 #import <NGObjWeb/WOApplication.h>
 #import <NGObjWeb/WOContext+SoObjects.h>
@@ -28,8 +25,6 @@
 
 #import <NGExtensions/NSObject+Logs.h>
 
-#import <SaxObjC/SaxObjC.h>
-#import <SaxObjC/SaxMethodCallHandler.h>
 #import <SaxObjC/SaxObjectDecoder.h>
 #import <SaxObjC/SaxXMLReaderFactory.h>
 
@@ -138,6 +133,7 @@ size_t curl_body_function_freebusy(void *ptr, size_t size, size_t nmemb, void *i
           curl_easy_setopt(curl, CURLOPT_POSTFIELDS, [rawRequest UTF8String]);
           //curl_easy_setopt(curl, CURLOPT_HEADERFUNCTION, curlHeaderFunction);
           //curl_easy_setopt(curl, CURLOPT_HEADER, 1);
+          curl_easy_setopt(curl, CURLOPT_TIMEOUT, 20L);
           curl_easy_setopt(curl, CURLOPT_SSL_VERIFYPEER, 0L);
           curl_easy_setopt(curl, CURLOPT_SSL_VERIFYHOST, 0L);
           curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, curl_body_function_freebusy);
@@ -146,8 +142,9 @@ size_t curl_body_function_freebusy(void *ptr, size_t size, size_t nmemb, void *i
 
           // Perform SOAP request
           rc = curl_easy_perform(curl);
-          if (rc != 0)
-            [self errorWithFormat: @"CURL error while accessing %@ (%d): ", url, rc, [NSString stringWithCString: error]];
+          if (rc != CURLE_OK)
+            [self errorWithFormat: @"CURL error while accessing %@ (%d): %@", url, rc,
+                  [NSString stringWithCString: strlen(error) ? error : curl_easy_strerror(rc)]];
           curl_easy_cleanup(curl);
           curl_slist_free_all(headerlist);
         
@@ -344,7 +341,7 @@ size_t curl_body_function_freebusy(void *ptr, size_t size, size_t nmemb, void *i
   NSMutableString *s;
 
   s = [NSMutableString stringWithCapacity: 64];
-  [s appendFormat:@"<0x%08X[%@]:", self, NSStringFromClass([self class])];
+  [s appendFormat:@"<%p[%@]:", self, NSStringFromClass([self class])];
   if (freeBusyViewType)
     [s appendFormat:@" freeBusyViewType='%@'", freeBusyViewType];
   if (mergedFreeBusy)
