@@ -1,6 +1,6 @@
 /* NGVCard+SOGo.h - this file is part of SOGo
  *
- * Copyright (C) 2009-2017 Inverse inc.
+ * Copyright (C) 2009-2020 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -56,6 +56,9 @@
 - (void) setNotes: (NSArray *) newNotes;
 - (NSArray *) notes;
 
+- (void) setTitles: (NSArray *) newTitles;
+- (NSArray *) titles;
+
 @end
 
 #endif /* NGVCARD_SOGO_H */
