@@ -1089,9 +1089,8 @@ static NSString    *userAgent      = nil;
 
 
   ud = [[context activeUser] userDefaults];
-  
 
-  [self setText: [sourceMail contentForReply]];
+  
   [self setHeaders: info];
   [self setIsHTML: [[ud mailComposeMessageType] isEqualToString: @"html"]];
   [self setSourceURL: [sourceMail imap4URLString]];
@@ -1099,7 +1098,11 @@ static NSString    *userAgent      = nil;
   [self setSourceIMAP4ID: [[sourceMail nameInContainer] intValue]];
   [self setSourceFolderWithMailObject: sourceMail];
 
-  [self setText: [sourceMail contentForReply]];
+  if ([[ud mailComposeMessageType] isEqualToString: @"html"]) {
+    [self setText: [NSString stringWithFormat: @"<br/><br/>%@", [sourceMail contentForReply]]];
+  } else {
+    [self setText: [NSString stringWithFormat: @"\n\n%@", [sourceMail contentForReply]]];
+  }
   shouldRetrieveAttachements = [[ud mailComposeMessageType] isEqualToString: @"html"];
 
   if (shouldRetrieveAttachements) {
@@ -1835,6 +1838,7 @@ static NSString    *userAgent      = nil;
   NSString *s, *dateString;
   NGMutableHashMap *map;
   id emails, from, replyTo;
+  BOOL addXForward = NO;
 
   map = [[[NGMutableHashMap alloc] initWithCapacity:16] autorelease];
 
@@ -1881,16 +1885,14 @@ static NSString    *userAgent      = nil;
   [map addObject: userAgent forKey: @"User-Agent"];
 
   /* add custom headers */
-  if ([(s = [[context request] headerForKey:@"x-webobjects-remote-host"]) length] > 0 &&
+  addXForward = ![[[context activeUser] domainDefaults] mailDisableXForward];
+  if (addXForward && [(s = [[context request] headerForKey:@"x-webobjects-remote-host"]) length] > 0 &&
       [s compare: @"localhost"] != NSOrderedSame)
-    [map addObject: s
-	    forKey: @"X-Forward"];
+    [map addObject: s forKey: @"X-Forward"];
   if ([(s = [headers objectForKey: @"X-Priority"]) length] > 0)
-    [map setObject: s
-            forKey: @"X-Priority"];
+    [map setObject: s forKey: @"X-Priority"];
   if ([(s = [headers objectForKey: @"Disposition-Notification-To"]) length] > 0)
-    [map setObject: s
-            forKey: @"Disposition-Notification-To"];
+    [map setObject: s forKey: @"Disposition-Notification-To"];
 
   [self _addHeaders: _headers toHeaderMap: map];
 
@@ -2403,9 +2405,9 @@ static NSString    *userAgent      = nil;
   //  - SOGoMailKeepDraftsAfterSend is not set;
   //  - draft is successfully deleted;
   //  - drafts mailbox exists.
+  [self delete];
   if (!error &&
       ![dd mailKeepDraftsAfterSend] &&
-      ![self delete] &&
       [imap4 doesMailboxExistAtURL: [container imap4URL]])
     [(SOGoDraftsFolder *) container expunge];
 
