@@ -277,6 +277,7 @@ unsigned char GetRruleMonthNum(unsigned char a, unsigned char b) {
   NSString *partName, *type, *subtype;
   NSString *value, *attendee;
   RTFHandler *handler;
+  NGMimeBodyPart* eventPart;
 
   DWORD signature;
   DDWORD *classification;
@@ -664,9 +665,10 @@ unsigned char GetRruleMonthNum(unsigned char a, unsigned char b) {
               if (debugOn)
                 NSLog(@"TNEF reconstructed vCalendar:\n%@", vcalendar);
 
-              [self bodyPartForData: [vcalendar dataUsingEncoding: NSUTF8StringEncoding]
+              eventPart = [self bodyPartForData: [vcalendar dataUsingEncoding: NSUTF8StringEncoding]
                            withType: @"text"
                          andSubtype: @"calendar"];
+              [self setPart: eventPart];
 
             }
           // Other classes to handle:
@@ -756,6 +758,17 @@ unsigned char GetRruleMonthNum(unsigned char a, unsigned char b) {
                         {
                           partName = [NSString stringWithUTF8String: (const char *)attachmentName->data];
 
+                          if (!partName) {
+                            // Switch to different encoding
+                            partName = [[NSString alloc] initWithData: [NSData dataWithBytes: attachmentName->data length: strlen(attachmentName->data)] encoding:NSISOLatin1StringEncoding];
+                            [partName autorelease];
+                          }
+                          if (!partName) {
+                            // Fallback
+                            [self warnWithFormat: @"Could not get TNEF attachment name, fallback to unamed.bin"];
+                            partName = @"unnamed.bin";
+                          }
+
                           type = @"application";
                           subtype = @"octet-stream";
 
