@@ -106,6 +106,9 @@ static Class NSStringK;
       _filter = nil;
       _userPasswordAlgorithm = nil;
       _listRequiresDot = YES;
+      _globalAddressBookFirstEntriesCount = -1;
+
+      _disableSubgroups = NO;
 
       _passwordPolicy = NO;
       _updateSambaNTLMPasswords = NO;
@@ -170,7 +173,7 @@ static Class NSStringK;
                inDomain: (NSString *) sourceDomain
 {
   SOGoDomainDefaults *dd;
-  NSNumber *udQueryLimit, *udQueryTimeout, *udGroupExpansionEnabled, *dotValue;
+  NSNumber *udQueryLimit, *udQueryTimeout, *udGroupExpansionEnabled, *dotValue, *disableSubgroupsValue;
 
   if ((self = [self init]))
     {
@@ -200,10 +203,19 @@ static Class NSStringK;
             andMultipleBookingsField: [udSource objectForKey: @"MultipleBookingsFieldName"]];
 
       dotValue = [udSource objectForKey: @"listRequiresDot"];
-      if (dotValue)
+      if (dotValue) {
         [self setListRequiresDot: [dotValue boolValue]];
+        if ([udSource objectForKey: @"globalAddressBookFirstEntriesCount"])
+          [self setGlobalAddressBookFirstEntriesCount: [[udSource objectForKey: @"globalAddressBookFirstEntriesCount"] intValue]];
+      }
+
+      disableSubgroupsValue = [udSource objectForKey: @"disableSubgroups"];
+      if (disableSubgroupsValue)
+        _disableSubgroups = [disableSubgroupsValue boolValue];
+
       [self setContactMapping: [udSource objectForKey: @"mapping"]
              andObjectClasses: [udSource objectForKey: @"objectClasses"]];
+             
 
       [self setModifiers: [udSource objectForKey: @"modifiers"]];
       ASSIGN(_abOU, [udSource objectForKey: @"abOU"]);
@@ -400,6 +412,16 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   return _listRequiresDot;
 }
 
+- (void) setGlobalAddressBookFirstEntriesCount: (int)value
+{
+  _globalAddressBookFirstEntriesCount = value;
+}
+
+- (int) globalAddressBookFirstEntriesCount
+{
+  return _globalAddressBookFirstEntriesCount;
+}
+
 - (NSArray *) searchFields
 {
   return _searchFields;
@@ -2339,16 +2361,21 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
               user = [SOGoUser userWithLogin: login  roles: nil];
               if (user)
                 {
-                  contactInfos = [self lookupContactEntryWithUIDorEmail: login inDomain: nil];
-                  if ([contactInfos objectForKey: @"isGroup"])
+                  if (!_disableSubgroups) {
+                    contactInfos = [self lookupContactEntryWithUIDorEmail: login inDomain: nil];
+                    if ([contactInfos objectForKey: @"isGroup"])
                     {
                       subusers = [self membersForGroupWithUID: login];
                       [members addObjectsFromArray: subusers];
                     }
-                  else
+                    else
                     {
                       [members addObject: user];
                     }
+                  } else {
+                    [members addObject: user];
+                  }
+                  
                 }
               [pool release];
             }
@@ -2361,16 +2388,20 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
               user = [SOGoUser userWithLogin: login  roles: nil];
               if (user)
                 {
-                  contactInfos = [self lookupContactEntryWithUIDorEmail: login inDomain: nil];
-                  if ([contactInfos objectForKey: @"isGroup"])
+                  if (!_disableSubgroups) {
+                    contactInfos = [self lookupContactEntryWithUIDorEmail: login inDomain: nil];
+                    if ([contactInfos objectForKey: @"isGroup"])
                     {
                       subusers = [self membersForGroupWithUID: login];
                       [members addObjectsFromArray: subusers];
                     }
-                  else
+                    else
                     {
                       [members addObject: user];
                     }
+                  } else {
+                    [members addObject: user];
+                  }
                 }
               [pool release];
             }
