@@ -609,6 +609,18 @@ static int cssEscapingCount;
   return newString;
 }
 
+
+- (NSString *) mailDomain
+{
+  NSArray *mailSeparated;
+
+  mailSeparated = [self componentsSeparatedByString: @"@"];
+  if([mailSeparated count] == 2)
+    return [mailSeparated objectAtIndex: 1];
+  [self logWithFormat: @"Error while extracting domain from : %@", self];
+  return nil;
+}
+
 - (NSString *) pureEMailAddress
 {
   NSString *pureAddress;
@@ -891,6 +903,28 @@ static int cssEscapingCount;
   return result;
 }
 
+/**
+ * Remove all HTML tags except for <a> </a>
+ * @return A clean string
+ */
+- (NSString *)removeHTMLTagsExceptAnchorTags {
+    NSError *error;
+    NSRegularExpression *regex;
+    NSString *stringWithoutHTML;
+    
+    error = nil;
+    
+    regex = [NSRegularExpression regularExpressionWithPattern: @"<(?!a|\\/a\\b)[^>]*>" options: NSRegularExpressionCaseInsensitive error: &error];
+    stringWithoutHTML = [regex stringByReplacingMatchesInString: self options: 0 range: NSMakeRange(0, [self length]) withTemplate:@""];
+
+    if (error) {
+      [self logWithFormat: @"Error while removing tags : %@", [error localizedDescription]];
+      return self;
+    }
+    
+    return stringWithoutHTML;
+}
+
 /**
  * Get the safe string avoiding HTML injection
  * @param stripHTMLCode Remove all HTML code from content
@@ -979,6 +1013,18 @@ static int cssEscapingCount;
       newResult = [regex stringByReplacingMatchesInString:result options:0 range:NSMakeRange(0, [result length]) withTemplate:@"<ifr***"];
       result = [NSString stringWithString: newResult];
 
+      // Remove <form
+      regex = [NSRegularExpression regularExpressionWithPattern:@"<[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*f[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*o[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*r[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*m" 
+                                  options: NSRegularExpressionCaseInsensitive error:&error];
+      newResult = [regex stringByReplacingMatchesInString:result options:0 range:NSMakeRange(0, [result length]) withTemplate:@"<for*"];
+      result = [NSString stringWithString: newResult];
+
+      // Remove </form
+      regex = [NSRegularExpression regularExpressionWithPattern:@"<[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*/[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*f[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*o[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*r[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*m" 
+                                  options: NSRegularExpressionCaseInsensitive error:&error];
+      newResult = [regex stringByReplacingMatchesInString:result options:0 range:NSMakeRange(0, [result length]) withTemplate:@"</for*"];
+      result = [NSString stringWithString: newResult];
+
       // Remove onload
       regex = [NSRegularExpression regularExpressionWithPattern:@"onload=" 
                                   options: NSRegularExpressionCaseInsensitive error:&error];
@@ -990,6 +1036,15 @@ static int cssEscapingCount;
                                   options: NSRegularExpressionCaseInsensitive error:&error];
       newResult = [regex stringByReplacingMatchesInString:result options:0 range:NSMakeRange(0, [result length]) withTemplate:@"onmouseo***="];
       result = [NSString stringWithString: newResult];
+
+      // Remove @import css (in style tags)
+      regex = [NSRegularExpression regularExpressionWithPattern:@"(<[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*s[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*t[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*y[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*l[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*e.*)([\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*@[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*i[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*m[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*p[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*o[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*r[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*t)(.*<[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*\\/[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*s[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*t[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*y[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*l[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*e[\\s\\u200B&#x09;&#x0A;&#x0D;\\\\0]*>)" 
+                                  options: NSRegularExpressionCaseInsensitive error:&error];
+      newResult = result;
+      while([regex numberOfMatchesInString:newResult options:0 range:NSMakeRange(0, [newResult length])] > 0) {
+        newResult = [regex stringByReplacingMatchesInString:newResult options:0 range:NSMakeRange(0, [newResult length]) withTemplate:@"$1@im****$3"];
+      }
+      result = [NSString stringWithString: newResult];
     }
   }  
   NS_HANDLER
@@ -1001,4 +1056,15 @@ static int cssEscapingCount;
   return result;
 }
 
+- (NSString *) cleanInvalidHTMLTags {
+  // Clean HTML invalid tags as reported in https://bugs.sogo.nu/view.php?id=5755
+  NSString *s;
+  
+  s = [NSString stringWithString: self];
+  s = [s stringByReplacingOccurrencesOfString:@"<!-->" withString:@""];
+  s = [s stringByReplacingOccurrencesOfString:@"<!--<!" withString:@"<!--"];
+
+  return s;
+}
+
 @end
