@@ -38,6 +38,7 @@
 - (BOOL) mailCustomFromEnabled;
 - (BOOL) mailAuxiliaryUserAccountsEnabled;
 
+- (BOOL) mailDisableXForward;
 - (NSString *) mailDomain;
 - (NSString *) imapServer;
 - (NSString *) sieveServer;
@@ -53,6 +54,7 @@
 - (BOOL) forwardEnabled;
 - (int) forwardConstraints;
 - (NSArray *) forwardConstraintsDomains;
+- (BOOL) notificationEnabled;
 - (BOOL) vacationEnabled;
 - (BOOL) vacationPeriodEnabled;
 - (NSString *) vacationDefaultSubject;
@@ -98,6 +100,10 @@
 
 - (BOOL) createIdentitiesDisabled;
 
+- (NSString *) passwordRecoveryFrom;
+
+- (BOOL) forceRawHtmlSignature;
+
 @end
 
 #endif /* SOGODOMAINDEFAULTS_H */
