@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2006-2016 Inverse inc.
+  Copyright (C) 2006-2021 Inverse inc.
 
   This file is part of SOGo.
 
@@ -41,6 +41,7 @@
 @class NSString;
 
 @class WOContext;
+@class WORequest;
 
 @class SOGoAppointmentFolder;
 @class SOGoAppointmentFolders;
@@ -112,7 +113,9 @@
 - (unsigned int) weekNumberForDate: (NSCalendarDate *) date;
 
 - (NSArray *) mailAccounts;
+- (NSArray *) mailAccountsNoRawHtmlSignature;
 - (NSArray *) mailAccountsWithDelegatedIdentities: (BOOL) appendDeletegatedIdentities;
+- (NSArray *)mailAccountsWithDelegatedIdentities:(BOOL)appendDeletegatedIdentities forceRawHtmlSignature:(BOOL)forceRawHtmlSignature;
 - (NSDictionary *) accountWithName: (NSString *) accountName;
 - (NSArray *) allIdentities;
 - (NSDictionary *) primaryIdentity;
@@ -120,6 +123,7 @@
 
 - (BOOL) isSuperUser;
 - (BOOL) canAuthenticate;
+- (NSString *) totpKey;
 
 /* resource */
 - (BOOL) isResource;
@@ -134,6 +138,10 @@
 - (SOGoAppointmentFolder *) personalCalendarFolderInContext: (WOContext *) context;
 - (SOGoContactFolder *) personalContactsFolderInContext: (WOContext *) context;
 
+/* Encryption */
++ (NSString *)getEncryptedUsernameIfNeeded:(NSString *)username request:(WORequest *)request;
++ (NSString *)getDecryptedUsernameIfNeeded:(NSString *)username request:(WORequest *)request;
+
 @end
 
 #endif /* __SOGoUser_H__ */
