@@ -1026,10 +1026,20 @@ static const NSString *kEncryptedUserNamePrefix = @"uenc";
 
 - (NSArray *) mailAccounts
 {
-  return [self mailAccountsWithDelegatedIdentities: YES];
+  return [self mailAccountsWithDelegatedIdentities: YES forceRawHtmlSignature: [[self domainDefaults] forceRawHtmlSignature]];
+}
+
+- (NSArray *) mailAccountsNoRawHtmlSignature
+{
+  return [self mailAccountsWithDelegatedIdentities: YES forceRawHtmlSignature: NO];
 }
 
 - (NSArray *) mailAccountsWithDelegatedIdentities: (BOOL) appendDeletegatedIdentities
+{
+  return [self mailAccountsWithDelegatedIdentities: appendDeletegatedIdentities forceRawHtmlSignature: [[self domainDefaults] forceRawHtmlSignature]];
+}
+
+- (NSArray *) mailAccountsWithDelegatedIdentities: (BOOL) appendDeletegatedIdentities forceRawHtmlSignature: (BOOL) forceRawHtmlSignature
 {
   NSArray *auxAccounts;
 
@@ -1091,7 +1101,42 @@ static const NSString *kEncryptedUserNamePrefix = @"uenc";
         }
     }
 
-  return mailAccounts;
+  // Patch for CKEditor 5
+  // HTML Signatures with tables are broken with CKEditor 5
+  // In this case, signatures may be encapsulated with a <div class="raw-html-embed">
+  // Details in https://bugs.sogo.nu/view.php?id=5920
+  NSMutableArray *tmpMailAccounts, *tmpIdentities;
+  NSDictionary *account, *identities, *identity;
+  NSMutableDictionary *tmpAccount, *tmpIdentity;
+  NSString *signature;
+
+  if (mailAccounts && [mailAccounts count] > 0) {
+    tmpMailAccounts = [NSMutableArray array];
+    for (account in mailAccounts) {
+      tmpAccount = [NSMutableDictionary dictionaryWithDictionary: account];
+      if ([account objectForKey: @"identities"]) {
+        identities = [account objectForKey: @"identities"];
+        tmpIdentities = [NSMutableArray array];
+        for (identity in identities) {
+          tmpIdentity = [NSMutableDictionary dictionaryWithDictionary: identity];
+          if ([tmpIdentity objectForKey: @"signature"] && [[tmpIdentity objectForKey: @"signature"] length] > 0) {
+            // Add raw html embed class
+            if ([[tmpIdentity objectForKey: @"signature"] rangeOfString:@"raw-html-embed"].location == NSNotFound
+                && [[[self userDefaults] mailComposeMessageType] isEqualToString: @"html"]
+                && forceRawHtmlSignature) {
+              signature = [NSString stringWithFormat:@"<div class=\"raw-html-embed sogo-raw-html-embed\">%@</div>", [tmpIdentity objectForKey: @"signature"]];
+              [tmpIdentity setObject:signature forKey:@"signature"];
+            }
+          }
+          [tmpIdentities addObject: tmpIdentity];
+        }
+        [tmpAccount setObject:tmpIdentities forKey: @"identities"];
+      }
+      [tmpMailAccounts addObject: tmpAccount];
+    }
+  }
+
+  return tmpMailAccounts;
 }
 
 - (NSDictionary *) accountWithName: (NSString *) accountName;
