@@ -32,6 +32,7 @@
 #import <Foundation/NSTimeZone.h>
 #import <Foundation/NSUserDefaults.h> /* for locale string constants */
 #import <Foundation/NSValue.h>
+#import <Foundation/NSNumberFormatter.h>
 
 #import <NGObjWeb/WOApplication.h>
 #import <NGObjWeb/WOContext+SoObjects.h>
@@ -340,20 +341,16 @@
                           && [[currentPart objectForKey:@"disposition"] objectForKey:@"type"] 
                           && [[[[currentPart objectForKey:@"disposition"] objectForKey:@"type"] uppercaseString] isEqualToString:@"INLINE"];
             isImage = [SOGoMailBodyPart bodyPartClassForMimeType: [contentType lowercaseString] inContext: [self context]] == [SOGoImageMailBodyPart class];
+            
 
             if (![ud hideInlineAttachments] || ([ud hideInlineAttachments] && !(isInline && isImage))) {
-              BOOL a = [currentPart objectForKey:@"disposition"] ;
-              BOOL b = [[[currentPart objectForKey:@"disposition"] allKeys] length] > 0 ;
-              BOOL c = [currentPart objectForKey:@"parameterList"] ;
-              BOOL d = [[currentPart objectForKey:@"parameterList"] objectForKey:@"name"];
-              BOOL foo = ([currentPart objectForKey:@"parameterList"]
-                                  && [[currentPart objectForKey:@"parameterList"] objectForKey:@"name"]
-                                );
-              hasAttachment = (([currentPart objectForKey:@"disposition"] 
+              hasAttachment = ((([currentPart objectForKey:@"disposition"] 
                                 && [[[currentPart objectForKey:@"disposition"] allKeys] length] > 0)
                                 || ([currentPart objectForKey:@"parameterList"]
                                   && [[currentPart objectForKey:@"parameterList"] objectForKey:@"name"]
-                                ));
+                                ))
+                                && !(isInline && contentType && [[contentType lowercaseString] isEqualToString:@"text/plain"])
+                                && !(isInline && contentType && [[contentType lowercaseString] isEqualToString:@"text/html"]));
             }
           } else if ([currentPart objectForKey:@"parts"]) {
             hasAttachment = [self parseParts: [currentPart objectForKey:@"parts"] hasAttachment: hasAttachment];
@@ -474,17 +471,19 @@
   EOQualifier *qualifier, *notDeleted, *searchQualifier;
   WORequest *request;
   NSDictionary *sortingAttributes, *content, *filter;
-  NSArray *filters, *labels;
-  NSString *searchBy, *searchInput, *searchString, *match, *label;
+  NSArray *filters, *labels, *searchInputSplit, *flags;
+  NSString *searchBy, *searchInput, *searchString, *match, *label, *operator, *sizeUnit, *dateFrom, *dateTo;
   NSMutableArray *qualifiers, *searchArray, *labelQualifiers;
+  NSNumberFormatter *formatter;
+  NSNumber *size;
   BOOL unseenOnly, flaggedOnly;
-  int max, i;
+  int max, i, j;
   
   request = [context request];
   content = [[request contentAsString] objectFromJSONString];
   notDeleted = [EOQualifier qualifierWithQualifierFormat: @"(not (flags = %@))", @"deleted"];
   qualifiers = [NSMutableArray arrayWithObject: notDeleted];
-  searchString = nil;
+  searchString = @"";
   match = nil;
   filters = [content objectForKey: @"filters"];
   labels = [content objectForKey: @"labels"];
@@ -497,35 +496,143 @@
       if (max > 0) {
         searchArray = [NSMutableArray arrayWithCapacity: max];
         for (i = 0; i < max; i++)
-          {
-            filter = [filters objectAtIndex:i];
-            searchBy = [filter objectForKey: @"searchBy"];
-            searchInput = [filter objectForKey: @"searchInput"];
-            if (searchBy && searchInput)
-              {
-                if ([[filter objectForKey: @"negative"] boolValue])
-                  searchString = [NSString stringWithFormat: @"(not (%@ doesContain: '%@'))", searchBy, searchInput];
-                else
-                  searchString = [NSString stringWithFormat: @"(%@ doesContain: '%@')", searchBy, searchInput];
+        {
+          filter = [filters objectAtIndex:i];
+          searchBy = [filter objectForKey: @"searchBy"];
+          searchInput = [filter objectForKey: @"searchInput"];
+          
+          if (searchBy && searchInput)
+            {
+              // Size
+              if ([searchBy isEqualToString: @"size"]) {
+                operator = [filter objectForKey: @"operator"];
+                sizeUnit = [filter objectForKey: @"sizeUnit"];
+                formatter = [[NSNumberFormatter alloc] init];
+                formatter.numberStyle = NSNumberFormatterDecimalStyle;
+                size = [formatter numberFromString: searchInput];
+                [formatter release];
+                if ([[sizeUnit lowercaseString] isEqualToString: @"kb"]) {
+                  size = [NSNumber numberWithLongLong: [size longLongValue] * 1024];
+                } else if ([[sizeUnit lowercaseString] isEqualToString: @"mb"]) {
+                  size = [NSNumber numberWithLongLong: [size longLongValue]  * 1024 * 1024];
+                } else if ([[sizeUnit lowercaseString] isEqualToString: @"gb"]) {
+                  size = [NSNumber numberWithLongLong: [size longLongValue] * 1024 * 1024 * 1024];
+                }
+                
+                searchString = [NSString stringWithFormat: @"(%@ %@ %@)", searchBy, operator, [size stringValue]];
+              } else if ([searchBy isEqualToString: @"date"]) {
+                // Date
+                operator = [filter objectForKey: @"operator"];
+                searchString = [NSString stringWithFormat: @"(%@ %@ (NSCalendarDate)\"%@\")", searchBy, operator, searchInput];
+              } else if ([searchBy isEqualToString: @"date_between"]) {
+                // Date between
+                dateFrom = [filter objectForKey: @"dateFrom"];
+                dateTo = [filter objectForKey: @"dateTo"];
+                searchString = [NSString stringWithFormat: @"(date >= (NSCalendarDate)\"%@\" AND date <= (NSCalendarDate)\"%@\")", dateFrom, dateTo];
+              } else if ([searchBy isEqualToString: @"attachment"]) {
+                // Attachment
+                searchString = [NSString stringWithFormat: @"(text = 'attachment;') AND (text = 'filename')"];
+              } else if ([searchBy isEqualToString: @"favorite"]) {
+                // Favorite
+                flaggedOnly = YES;
+              } else if ([searchBy isEqualToString: @"unseen"]) {
+                // Unseen
+                unseenOnly = YES;
+              } else if ([searchBy isEqualToString: @"contains"]) {
+                // Contains
+                // Split on space to check each word
+                searchInput = [searchInput stringByReplacingOccurrencesOfString:@"'" withString:@"\\'"];
+                searchInputSplit = [searchInput componentsSeparatedByString:@" "];
+                if ([searchInputSplit count] > 1) {
+                  searchString = @"(";
+                  j = 0;
+                  for (searchInput in searchInputSplit) {
+                    if (j > 0) {
+                      searchString = [NSString stringWithFormat: @"%@ OR", searchString];
+                    }
+                    
+                    searchString = [NSString stringWithFormat: @"%@ (subject doesContain: '%@' OR body doesContain: '%@' OR text = 'filename=*%@*')", 
+                    searchString, searchInput, searchInput, searchInput];
+                    j++;
+                  }
+                  searchString = [NSString stringWithFormat: @"%@)", searchString];
+                } else {
+                  searchString = [NSString stringWithFormat: @"(subject doesContain: '%@' OR body doesContain: '%@' OR text = 'filename=*%@*')", 
+                    searchInput, searchInput, searchInput];
+                }
+              } else if ([searchBy isEqualToString: @"not_contains"]) {
+                // Not contains
+                searchInput = [searchInput stringByReplacingOccurrencesOfString:@"'" withString:@"\\'"];
+                searchString = [NSString stringWithFormat: @"(NOT (subject doesContain: '%@') AND NOT (body doesContain: '%@'))", 
+                searchInput, searchInput];
 
+                // Split on space to check each word
+                searchInput = [searchInput stringByReplacingOccurrencesOfString:@"'" withString:@"\\'"];
+                searchInputSplit = [searchInput componentsSeparatedByString:@" "];
+                if ([searchInputSplit count] > 1) {
+                  searchString = @"(";
+                  j = 0;
+                  for (searchInput in searchInputSplit) {
+                    if (j > 0) {
+                      searchString = [NSString stringWithFormat: @"%@ AND", searchString];
+                    }
+                    
+                    searchString = [NSString stringWithFormat: @"%@ (NOT (subject doesContain: '%@') AND NOT (body doesContain: '%@'))", 
+                    searchString, searchInput, searchInput];
+                    j++;
+                  }
+                  searchString = [NSString stringWithFormat: @"%@)", searchString];
+                } else {
+                  searchString = [NSString stringWithFormat: @"(NOT (subject doesContain: '%@') AND NOT (body doesContain: '%@'))", 
+                    searchInput, searchInput];
+                }
+                } else if ([searchBy isEqualToString: @"flags"]) {
+                // Flags
+                flags = [filter objectForKey: @"flags"];
+                if (flags && [flags count] > 0) {
+                  searchString = @"(";
+                  
+                  for (j = 0 ; j < [flags count] ; j++) {
+                    if (j > 0)
+                      searchString = [NSString stringWithFormat: @"%@ AND", searchString];
+                    searchString = [NSString stringWithFormat: @"%@ (flags = '%@')", 
+                                      searchString, 
+                                      [[flags objectAtIndex: j] stringByReplacingOccurrencesOfString: @"_$" withString:@"$"]];
+                  }
+                  searchString = [NSString stringWithFormat: @"%@)", searchString];
+                }
+              } else {
+                // Others
+                searchString = [NSString stringWithFormat: @"(%@ doesContain: '%@')", searchBy, searchInput];
+              }
+
+              if ([[filter objectForKey: @"negative"] boolValue])
+                searchString = [NSString stringWithFormat: @"(not %@)", searchString];
+              
+
+              if (searchString && [searchString length] > 0) {
                 searchQualifier = [EOQualifier qualifierWithQualifierFormat: searchString];
                 if (searchQualifier)
                   [searchArray addObject: searchQualifier];
               }
-            else
-              {
-                [self errorWithFormat: @"Missing parameters in search filter: %@", filter];
-              }
-          }
-        sortingAttributes = [content objectForKey: @"sortingAttributes"];
-        if (sortingAttributes)
-          match = [sortingAttributes objectForKey: @"match"]; // AND, OR
-        if ([match isEqualToString: @"OR"])
-          qualifier = [[EOOrQualifier alloc] initWithQualifierArray: searchArray];
-        else
-          qualifier = [[EOAndQualifier alloc] initWithQualifierArray: searchArray];
-        [qualifier autorelease];
-        [qualifiers addObject: qualifier];
+            }
+          else
+            {
+              [self errorWithFormat: @"Missing parameters in search filter: %@", filter];
+            }
+        }
+
+        if ([searchArray count] > 0) {
+          sortingAttributes = [content objectForKey: @"sortingAttributes"];
+          if (sortingAttributes)
+            match = [sortingAttributes objectForKey: @"match"]; // AND, OR
+          if ([match isEqualToString: @"OR"])
+            qualifier = [[EOOrQualifier alloc] initWithQualifierArray: searchArray];
+          else
+            qualifier = [[EOAndQualifier alloc] initWithQualifierArray: searchArray];
+          [qualifier autorelease];
+          [qualifiers addObject: qualifier];
+        }
       }
     }
 
@@ -722,14 +829,25 @@
 
 - (NSDictionary *) getUIDsInFolder: (SOGoMailFolder *) folder
                        withHeaders: (BOOL) includeHeaders
+{
+  return [self getUIDsInFolder: folder
+                   withHeaders: includeHeaders
+               onlyAttachments: NO];
+}
+
+- (NSDictionary *) getUIDsInFolder: (SOGoMailFolder *) folder
+                       withHeaders: (BOOL) includeHeaders
+                   onlyAttachments: (BOOL) onlyAttachments
 {
   NSArray *uids, *threadedUids, *headers;
   NSMutableDictionary *data;
+  NSMutableArray *tmpHeaders, *tmpUids;
+  NSNumber *uid;
   SOGoMailAccount *account;
   id quota;
 
   NSRange r;
-  int count;
+  int count, i, j;
 
   data = [NSMutableDictionary dictionary];
 
@@ -765,11 +883,12 @@
 
       a = [uids flattenedArray];
       count = [a count];
-      if (count > headersPrefetchMaxSize)
+      if (count > headersPrefetchMaxSize && !onlyAttachments) // Only attachment to get all messages
         count = headersPrefetchMaxSize;
       r = NSMakeRange(0, count);
       headers = [self getHeadersForUIDs: [a subarrayWithRange: r]
                                inFolder: folder];
+
       [data setObject: headers forKey: @"headers"];
     }
 
@@ -782,6 +901,7 @@
       else
         sortByThread = NO;
     }
+
   if (uids != nil)
     [data setObject: uids forKey: @"uids"];
   [data setObject: [NSNumber numberWithBool: sortByThread] forKey: @"threaded"];
@@ -849,8 +969,8 @@
  */
 - (id <WOActionResults>) getUIDsAction
 {
-  BOOL noHeaders;
-  NSDictionary *data, *requestContent;
+  BOOL noHeaders, onlyAttachments;
+  NSDictionary *data, *requestContent, *filter;
   SOGoMailFolder *folder;
   WORequest *request;
   WOResponse *response;
@@ -861,8 +981,26 @@
   folder = [self clientObject];
   
   noHeaders = [[[requestContent objectForKey: @"sortingAttributes"] objectForKey: @"noHeaders"] boolValue];
+  
+  if ([[folder nameInContainer] isEqualToString: @"folderOther_SP_Users"]) {
+    // When the folder is folderOther_SP_Users (shared main folder), return no mailboxes
+    return response = [self responseWithStatus: 200
+                    andJSONRepresentation: [NSDictionary dictionaryWithObject: [NSArray array] forKey:@"mailboxes"]];
+  }
+  
+  onlyAttachments = NO;
+  if (requestContent 
+      && [requestContent objectForKey: @"filters"]
+      && [[requestContent objectForKey: @"filters"] count] > 0) {
+        for (filter in [requestContent objectForKey: @"filters"]) {
+          if ([filter objectForKey: @"searchBy"]
+              && [[filter objectForKey: @"searchBy"] isEqualToString: @"attachment"])
+              onlyAttachments = YES;
+        }
+  }
   data = [self getUIDsInFolder: folder
-                   withHeaders: !noHeaders];
+                   withHeaders: !noHeaders
+               onlyAttachments: onlyAttachments];
 
   if (data != nil)
     response = [self responseWithStatus: 200 andJSONRepresentation: data];
@@ -1063,13 +1201,14 @@
 
           // UID
           [msg addObject: [message objectForKey: @"uid"]];
-          [headers addObject: msg];
 
           // isAnswered
           [msg addObject: [NSNumber numberWithBool: [self isMessageAnswered]]];
 
           // isForwarded
           [msg addObject: [NSNumber numberWithBool: [self isMessageForwarded]]];
+
+          [headers addObject: msg];
       
           [self setMessage: [msgsList nextObject]];
 
