@@ -51,6 +51,7 @@
 #import <SOGo/SOGoWebAuthenticator.h>
 #import <SOGo/SOGoEmptyAuthenticator.h>
 #import <SOGo/SOGoMailer.h>
+#import <SOGo/SOGoAdmin.h>
 
 #if defined(MFA_CONFIG)
 #include <liboath/oath.h>
@@ -254,6 +255,7 @@ static const NSString *kJwtKey = @"jwt";
 
       loggedInUser = [SOGoUser userWithLogin: username];
       ud = [loggedInUser userDefaults];
+      us = [loggedInUser userSettings];
 
 #if defined(MFA_CONFIG)
       if ([ud totpEnabled])
@@ -309,7 +311,6 @@ static const NSString *kJwtKey = @"jwt";
             } //  if ([verificationCode length] == 6 && [verificationCode unsignedIntValue] > 0)
           else
             {
-              us = [loggedInUser userSettings];
               if ([us dictionaryForKey: @"General"] && ![[us dictionaryForKey: @"General"] objectForKey: @"PrivateSalt"])
                 {
                   // Since v5.3.0, a new salt is used for TOTP. If it's missing, disable TOTP and alert the user.
@@ -331,39 +332,45 @@ static const NSString *kJwtKey = @"jwt";
             }
         }
 #endif
+      
+      if ([us objectForKey: @"ForceResetPassword"]) {
+        response = [self _responseWithLDAPPolicyError: PolicyPasswordExpired];
+      } else {
+        [self _checkAutoReloadWebCalendars: loggedInUser];
 
-      [self _checkAutoReloadWebCalendars: loggedInUser];
+        [json setObject: [loggedInUser cn]
+                forKey: @"cn"];
+        [json setObject: [NSNumber numberWithInt: expire]
+                forKey: @"expire"];
+        [json setObject: [NSNumber numberWithInt: grace]
+                forKey: @"grace"];
+        [json setObject: [SOGoUser getEncryptedUsernameIfNeeded: username request: request]
+                forKey: @"username"];
 
-      [json setObject: [loggedInUser cn]
-               forKey: @"cn"];
-      [json setObject: [NSNumber numberWithInt: expire]
-               forKey: @"expire"];
-      [json setObject: [NSNumber numberWithInt: grace]
-               forKey: @"grace"];
+        response = [self responseWithStatus: 200
+                      andJSONRepresentation: json];
 
-      response = [self responseWithStatus: 200
-                    andJSONRepresentation: json];
+        authCookie = [auth cookieWithUsername: username
+                                  andPassword: password
+                                    inContext: context];
+        [response addCookie: authCookie];
 
-      authCookie = [auth cookieWithUsername: username
-                                andPassword: password
-                                  inContext: context];
-      [response addCookie: authCookie];
+        // We prepare the XSRF protection cookie
+        creds = [auth parseCredentials: [authCookie value]];
+        xsrfCookie = [WOCookie cookieWithName: @"XSRF-TOKEN"
+                                        value: [[SOGoSession valueForSessionKey: [creds lastObject]] asSHA1String]];
+        [xsrfCookie setPath: [NSString stringWithFormat: @"/%@/", [[context request] applicationName]]];
+        [response addCookie: xsrfCookie];
 
-      // We prepare the XSRF protection cookie
-      creds = [auth parseCredentials: [authCookie value]];
-      xsrfCookie = [WOCookie cookieWithName: @"XSRF-TOKEN"
-                                      value: [[SOGoSession valueForSessionKey: [creds lastObject]] asSHA1String]];
-      [xsrfCookie setPath: [NSString stringWithFormat: @"/%@/", [[context request] applicationName]]];
-      [response addCookie: xsrfCookie];
-
-      supportedLanguages = [[SOGoSystemDefaults sharedSystemDefaults]
-                             supportedLanguages];
-      [context setActiveUser: loggedInUser];
-      if (language && [supportedLanguages containsObject: language])
-	{
-	  [ud setLanguage: language];
-	  [ud synchronize];
-	}
+        supportedLanguages = [[SOGoSystemDefaults sharedSystemDefaults]
+                              supportedLanguages];
+        [context setActiveUser: loggedInUser];
+        if (language && [supportedLanguages containsObject: language])
+        {
+          [ud setLanguage: language];
+          [ud synchronize];
+        }
+      }
     }
   else
     {
@@ -490,9 +497,8 @@ static const NSString *kJwtKey = @"jwt";
     }
   else
     {
-      newLocation
-        = [SOGoCASSession CASURLWithAction: @"login"
-                             andParameters: [self _casRedirectKeys]];
+      newLocation = [SOGoCASSession CASURLWithAction: @"login"
+                                       andParameters: [self _casRedirectKeys]];
       casLocationCookie = [self _authLocationCookie: NO
                                            withName: @"cas-location"];
     }
@@ -569,7 +575,7 @@ static const NSString *kJwtKey = @"jwt";
       response
 	= [self redirectToLocation: [NSString stringWithFormat: @"%@%@",
 					      oldLocation,
-                                              [login stringByEscapingURL]]];
+                                              [[SOGoUser getEncryptedUsernameIfNeeded:login request: [context request]] stringByEscapingURL]]];
     }
   else
     {
@@ -655,9 +661,10 @@ static const NSString *kJwtKey = @"jwt";
   return [self labelForKey: [self language]];
 }
 
+
 - (NSArray *) languages
 {
-  return [[SOGoSystemDefaults sharedSystemDefaults] supportedLanguages];
+  return [[[SOGoSystemDefaults sharedSystemDefaults] supportedLanguages] sortedArrayUsingFunction: languageSort context: self];
 }
 
 - (NSString *) languageText
@@ -691,6 +698,8 @@ static const NSString *kJwtKey = @"jwt";
   WOResponse *response;
   WORequest *request;
   BOOL passwordRecovery;
+  SOGoUserSettings *us;
+  SOGoUser *loggedInUser;
 
   request = [context request];
   message = [[request contentAsString] objectFromJSONString];
@@ -772,7 +781,18 @@ static const NSString *kJwtKey = @"jwt";
                 username = [NSString stringWithFormat: @"%@@%@", username, domain];
             }
 
-          response = [self responseWith204];
+          loggedInUser = [SOGoUser userWithLogin: username];
+          
+          if (loggedInUser) {
+            us = [loggedInUser userSettings];
+            if (us && [us objectForKey: @"ForceResetPassword"]) {
+              [us disableForceResetPassword];
+            }
+          }
+          
+          response = [self responseWithStatus: 200 andJSONRepresentation: 
+                  [NSDictionary dictionaryWithObjectsAndKeys: [SOGoUser getEncryptedUsernameIfNeeded:username request: request], @"username", nil]];
+
           if (!passwordRecovery) {
             authCookie = [auth cookieWithUsername: username
                                       andPassword: newPassword
@@ -852,11 +872,18 @@ static const NSString *kJwtKey = @"jwt";
   if (!mode && jwtToken) {
     response = [self _standardDefaultAction];
   } else if ([mode isEqualToString: SOGoPasswordRecoverySecondaryEmail]) {
-    if (mailDomain && username) {
+    if (username) {
+        ownerUser = [SOGoUser userWithLogin: username];
+        dd = [ownerUser domainDefaults];
+
         // Email recovery
 
         // Create email from
-        fromEmail = [NSString stringWithFormat:@"noreply@%@", mailDomain];
+        if (mailDomain) {
+          fromEmail = [NSString stringWithFormat:@"noreply@%@", mailDomain];
+        } else {
+          fromEmail = [dd passwordRecoveryFrom];
+        }
 
         // Get password recovery email
         info = [um contactInfosForUserWithUIDorEmail: username];
@@ -870,8 +897,6 @@ static const NSString *kJwtKey = @"jwt";
           jwtToken = [um generateAndSavePasswordRecoveryTokenWithUid: uid username: username domain: domain];
 
           // Send mail
-          ownerUser = [SOGoUser userWithLogin: username];
-          dd = [ownerUser domainDefaults];
           mailer = [SOGoMailer mailerWithDomainDefaults: dd];
           url = [NSString stringWithFormat:@"%@%@?token=%@"
                       , [[request headers] objectForKey:@"origin"]
@@ -905,7 +930,7 @@ static const NSString *kJwtKey = @"jwt";
                               andString: @"Invalid configuration for email password recovery"];
         }
     } else {
-      [self logWithFormat: @"No user domain found for password recovery"];
+      [self logWithFormat: @"No user found for password recovery"];
       response = [self responseWithStatus: 403
                               andString: @"Invalid configuration for email password recovery"];
     }
@@ -1019,4 +1044,20 @@ static const NSString *kJwtKey = @"jwt";
 #endif
 }
 
+
+- (NSString *)motd
+{
+  return [[SOGoAdmin sharedInstance] getMotd];
+}
+
+- (NSString *)motdEscaped
+{
+  return [[[SOGoAdmin sharedInstance] getMotd] removeHTMLTagsExceptAnchorTags];
+}
+
+- (BOOL)hasMotd
+{
+  return [[SOGoAdmin sharedInstance] getMotd] && [[[SOGoAdmin sharedInstance] getMotd] length] > 1;
+}
+
 @end /* SOGoRootPage */
