@@ -1,6 +1,6 @@
 /* UIxComponentEditor.h - this file is part of SOGo
  *
- * Copyright (C) 2006-2015 Inverse inc.
+ * Copyright (C) 2006-2022 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +33,8 @@
   SOGoAppointmentFolder *componentCalendar;
 }
 
-- (BOOL) isReadOnly;
+- (BOOL) isEditable;
+- (BOOL) isErasable;
 - (BOOL) userHasRSVP;
 - (NSNumber *) reply;
 - (BOOL) isChildOccurrence;
