@@ -18,7 +18,7 @@ module.exports = function(grunt) {
   };
   var custom_vendor_files = {
     'js/vendor/angular-file-upload.min.js': ['node_modules/angular-file-upload/dist/angular-file-upload.js', 'js/Common/angular-file-upload.trump.js'],
-    'js/vendor/FileSaver.min.js': ['node_modules/file-saver/dist/FileSaver.js']
+    'js/vendor/FileSaver.min.js': ['node_modules/file-saver/dist/FileSaver.js', 'js/vendor/ckeditor/build/translations/*.js']
   };
 
   const sass = require('sass');
@@ -141,7 +141,8 @@ module.exports = function(grunt) {
       '<%= src %>/ng-sortable/dist/ng-sortable.min.js{,map}',
       '<%= src %>/lodash/lodash{,.min}.js',
       '<%= src %>/qrcodejs/qrcode{,.min}.js',
-      '<%= src %>/punycode/punycode.js'
+      '<%= src %>/punycode/punycode.js',
+      '<%= src %>/mark.js/dist/mark.min.js'
     ];
     for (var j = 0; j < js.length; j++) {
       var files = grunt.file.expand(grunt.template.process(js[j], {data: options}));
