@@ -103,7 +103,12 @@
     return AddressBook.$$resource.fetch(null, 'allContactSearch', params).then(function(response) {
       var results, card, index,
           compareIds = function(data) {
-            return this.id == data.id;
+            if(this.sourceID === undefined || data.sourceid === undefined) {
+              return this.id == data.id;
+            }
+            else {
+              return this.id == data.id && this.sourceID == data.sourceid;
+            }
           };
       if (excludedCards) {
         // Remove excluded cards from results
@@ -130,7 +135,7 @@
           cards.splice(index, 0, card);
         }
       });
-      AddressBook.$log.debug(cards);
+      // AddressBook.$log.debug(cards);
       return cards;
     });
   };
@@ -559,7 +564,7 @@
           // Respect the order of the results
           _.forEach(results, function(cardId, index) {
             var oldIndex, removedCards;
-            if (cards[index].id != cardId) {
+            if (!_.isUndefined(cards[index]) && cards[index].id != cardId) {
               oldIndex = _.findIndex(cards, _.bind(compareIds, cardId));
               removedCards = cards.splice(oldIndex, 1);
               cards.splice(index, 0, removedCards[0]);
@@ -744,6 +749,34 @@
     }
   };
 
+  /**
+   * @function downloadProvisioningProfile
+   * @memberof AddressBook.prototype
+   * @desc Download provisioning profile for Apple's devices
+   * @returns a promise of the HTTP operation
+   */
+  AddressBook.prototype.downloadProvisioningProfile = function () {
+    var options, resource, index, ownerPaths, realOwnerId, path;
+
+    options = {
+      type: 'application/octet-stream',
+      filename: 'addressbook.mobileconfig'
+    }
+
+    if (this.isSubscription) {
+      index = this.urls.cardDavURL.indexOf('/dav/');
+      ownerPaths = this.urls.cardDavURL.substring(index + 5).split(/\//);
+      realOwnerId = ownerPaths[0];
+      resource = AddressBook.$$resource.userResource(realOwnerId);
+      path = ownerPaths[1] + '/' + ownerPaths[2];
+    } else {
+      resource = AddressBook.$$resource;
+      path = this.id;
+    }
+
+    return resource.open(path, 'mobileconfig', null, options);
+  };
+
   /**
    * @function $unwrap
    * @memberof AddressBook.prototype
@@ -850,8 +883,10 @@
    * @param {promise} futureHeadersData - a promise of the metadata of some cards
    */
   AddressBook.prototype.$unwrapHeaders = function(futureHeadersData) {
-    var _this = this;
+    var _this = this,
+        deferred = AddressBook.$q.defer();
 
+    this.$futureHeadersData = deferred.promise;
     futureHeadersData.then(function(data) {
       AddressBook.$timeout(function() {
         var headers, j;
@@ -867,8 +902,13 @@
             }
           });
         }
+        deferred.resolve(_this.$cards);
       });
+    }, function() {
+      deferred.reject();
     });
+
+    return this.$futureHeadersData;
   };
 
   /**
